==> kdLaunchPad-1.0.4.tar.gz: kdLaunchPad-1.0.4/setup.py <==
#!/usr/bin/env python
#-*- coding:utf-8 -*-

from setuptools import setup, find_packages
from setuptools.command.install import install
from os.path import expanduser,join
        
with open("README.md", "r",encoding="utf-8") as fh:
    long_description = fh.read()

# class install_cmd(install):
#     def run(self):
#         install.run(self)   
#         print("开始创建菜单")
#         with open(join(expanduser("~"), 'Desktop','kdLaunchPad.sh'),"w+") as f:
#             f.write("#!/bin/sh\nkdLaunchPad")
        
setup(
#     固定部分
    name="kdLaunchPad",
    version="1.0.4",
    author="bkdwei",
    author_email="bkdwei@163.com",
    maintainer="韦坤东",
    maintainer_email="bkdwei@163.com",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/bkdwei/main",
    license="GPLv3+",
    platforms=["any"],
    setup_requires=["shortcutter"],
#     需要安装的依赖
    install_requires=["PyQt5",],
    packages=find_packages(),
    zip_safe=False,
    include_package_data=True,
    python_requires='>=3.4',

#     可变部分
    description="auto run some programs after system start",
    keywords=("main","autoStarter"),
#     package_data={"":["*","image/*"],},
#     data_files=[('/usr/share/applications', ['data/kdLaunchPad.desktop'])],
#    https://pypi.org/classifiers/
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: X11 Applications :: Qt",
        "Intended Audience :: End Users/Desktop",
        "Natural Language :: Chinese (Simplified)",
        "Topic :: System :: Boot :: Init",
        "Programming Language :: Python :: 3",
        " License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
        
    ],
    
     # 添加这个选项，在windows下Python目录的scripts下生成exe文件
     # 注意：模块与函数之间是冒号:
     # 终端运行用console_scripts
    entry_points={
        'gui_scripts': [
            'kdLaunchPad=kdLaunchPad.kdLaunchPad:main'
        ],    
    }
#     cmdclass={
#         'install': install_cmd,
#     }
)

==> kdLaunchPad-1.0.5.tar.gz: kdLaunchPad-1.0.5/setup.py <==
#!/usr/bin/env python
#-*- coding:utf-8 -*-

from setuptools import setup, find_packages
from install_script import install_cmd 
        
with open("README.md", "r",encoding="utf-8") as fh:
    long_description = fh.read()

        
setup(
#     固定部分
    name="kdLaunchPad",
    version="1.0.5",
    author="bkdwei",
    author_email="bkdwei@163.com",
    maintainer="韦坤东",
    maintainer_email="bkdwei@163.com",
    long_description=long_description,
#     long_description_content_type="text/markdown",
    url="https://github.com/bkdwei/kdLaunchPad",
    license="GPLv3+",
    platforms=["any"],
    
#     需要安装的依赖
    install_requires=["PyQt5"],
    packages=find_packages(),
    zip_safe=False,
    include_package_data=True,
    python_requires='>=3.4',

#     可变部分
    description="auto run some programs after system start",
    keywords=("kdLaunchPad","autoStarter"),
#    https://pypi.org/classifiers/
    classifiers=[
        "Development Status :: 5 - Production/Stable",
        "Environment :: X11 Applications :: Qt",
        "Intended Audience :: End Users/Desktop",
        "Natural Language :: Chinese (Simplified)",
        "Topic :: System :: Boot :: Init",
        "Programming Language :: Python :: 3",
        " License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)",
        "Operating System :: OS Independent",
        
    ],
    
     # 添加这个选项，在windows下Python目录的scripts下生成exe文件
     # 注意：模块与函数之间是冒号:
     # 终端运行用console_scripts
    entry_points={
        'gui_scripts': [
            'kdLaunchPad=kdLaunchPad.kdLaunchPad:main'
        ],    
    },
    cmdclass={
        'install': install_cmd,
    }
)
